@@ -398,7 +398,7 @@ class Multiplex:
 			else:
 				sys.stdout.write("Login: ")
 				login=sys.stdin.readline().strip()
-				if re.match('^[0-9A-Za-z-_.]+$',login):
+				if re.match('^[0-9A-Za-z-_. ]+$',login):
 					cmd=['ssh']
 					cmd+=['-oPreferredAuthentications=keyboard-interactive,password']
 					cmd+=['-oNoHostAuthenticationForLocalhost=yes']
@@ -555,7 +555,11 @@ def main():
 		print 'AjaxTerm at http://localhost:%s/' % o.port
 	at=AjaxTerm(o.cmd,o.index_file)
 #	f=lambda:os.system('firefox http://localhost:%s/&'%o.port)
-	qweb.qweb_wsgi_autorun(at,ip='localhost',port=int(o.port),threaded=0,log=o.log,callback_ready=None)
+#	qweb.qweb_wsgi_autorun(at,ip='localhost',port=int(o.port),threaded=0,log=o.log,callback_ready=None)
+	try:
+		qweb.QWebWSGIServer(at,ip='localhost',port=int(o.port),threaded=0,log=o.log).serve_forever()
+	except KeyboardInterrupt,e:
+		sys.excepthook(*sys.exc_info())
 	at.multi.die()
 
 if __name__ == '__main__':
